@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionkeep.h"
-#include "editor/sieveeditorutil.h"
-#include "widgets/selectflagswidget.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
+#include "editor/sieveeditorutil.h"
+#include "widgets/selectflagswidget.h"
 
-#include <KLocalizedString>
-#include <QLabel>
-#include <QHBoxLayout>
-#include <QXmlStreamReader>
 #include "libksieve_debug.h"
+#include <KLocalizedString>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 SieveActionKeep::SieveActionKeep(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
@@ -41,20 +41,21 @@ QString SieveActionKeep::code(QWidget *w) const
 QString SieveActionKeep::help() const
 {
     return i18n(
-        "The \"keep\" action is whatever action is taken in lieu of all other actions, if no filtering happens at all; generally, this simply means to file the message into the user's main mailbox.");
+        "The \"keep\" action is whatever action is taken in lieu of all other actions, if no filtering happens at all; generally, this simply means to file "
+        "the message into the user's main mailbox.");
 }
 
 QWidget *SieveActionKeep::createParamWidget(QWidget *parent) const
 {
     if (mHasFlagSupport) {
-        QWidget *w = new QWidget(parent);
-        auto *lay = new QHBoxLayout;
+        auto w = new QWidget(parent);
+        auto lay = new QHBoxLayout;
         lay->setContentsMargins({});
         w->setLayout(lay);
-        QLabel *addFlags = new QLabel(i18n("Add flags:"));
+        auto addFlags = new QLabel(i18n("Add flags:"));
         lay->addWidget(addFlags);
 
-        auto *flagsWidget = new SelectFlagsWidget;
+        auto flagsWidget = new SelectFlagsWidget;
         connect(flagsWidget, &SelectFlagsWidget::valueChanged, this, &SieveActionKeep::valueChanged);
         flagsWidget->setObjectName(QStringLiteral("flagswidget"));
         lay->addWidget(flagsWidget);
@@ -68,22 +69,26 @@ void SieveActionKeep::setParamWidgetValue(QXmlStreamReader &element, QWidget *w,
 {
     if (mHasFlagSupport) {
         while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const QStringRef tagName = element.name();
+#else
+            const QStringView tagName = element.name();
+#endif
             if (tagName == QLatin1String("list")) {
-                auto *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
+                auto flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
                 flagsWidget->setFlags(AutoCreateScriptUtil::listValue(element));
             } else if (tagName == QLatin1String("str")) {
-                auto *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
+                auto flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
                 flagsWidget->setFlags(QStringList() << element.readElementText());
             } else if (tagName == QLatin1String("tag") && element.readElementText() == QLatin1String("flags")) {
-                //nothing :)
-                //Don't skip here.
+                // nothing :)
+                // Don't skip here.
             } else if (tagName == QLatin1String("crlf")) {
                 element.skipCurrentElement();
-                //nothing
+                // nothing
             } else if (tagName == QLatin1String("comment")) {
                 element.skipCurrentElement();
-                //implement in the future ?
+                // implement in the future ?
             } else {
                 unknownTag(tagName, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveActionAbstractFlags::setParamWidgetValue unknown tag :" << tagName;
