@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SELECTVACATIONCOMBOBOX_H
-#define SELECTVACATIONCOMBOBOX_H
+#pragma once
 #include <QComboBox>
 
 namespace KSieveUi
@@ -27,4 +26,3 @@ private:
 };
 }
 
-#endif // SELECTVACATIONCOMBOBOX_H
