@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVECONDITIONSIZE_H
-#define SIEVECONDITIONSIZE_H
+#pragma once
 
 #include "sievecondition.h"
 
@@ -27,4 +26,3 @@ public:
 };
 }
 
-#endif // SIEVECONDITIONSIZE_H
