@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVEEDITORGRAPHICALMODEWIDGETABSTRACT_H
-#define SIEVEEDITORGRAPHICALMODEWIDGETABSTRACT_H
+#pragma once
 
 #include "ksieveui_private_export.h"
 #include <editor/sieveeditorabstractwidget.h>
@@ -31,4 +30,3 @@ public:
 };
 }
 
-#endif // SIEVEEDITORGRAPHICALMODEWIDGETABSTRACT_H
