@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVESCRIPTDESCRIPTIONDIALOG_H
-#define SIEVESCRIPTDESCRIPTIONDIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -34,4 +33,3 @@ private:
 };
 }
 
-#endif // SIEVESCRIPTDESCRIPTIONDIALOG_H
