@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef SIEVEEDITORUTIL_H
-#define SIEVEEDITORUTIL_H
+#pragma once
 
 #include <QUrl>
 
@@ -76,4 +75,3 @@ QUrl helpUrl(KSieveUi::SieveEditorUtil::HelpVariableName type);
 }
 }
 
-#endif // SIEVEEDITORUTIL_H
