@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEEDITORHELPHTMLWIDGET_H
-#define SIEVEEDITORHELPHTMLWIDGET_H
+#pragma once
 
 #include "ksieveui_export.h"
 #include <QUrl>
@@ -63,4 +62,3 @@ private:
 };
 }
 
-#endif // SIEVEEDITORHELPHTMLWIDGET_H
