@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVESCRIPTDEBUGGERWARNING_H
-#define SIEVESCRIPTDEBUGGERWARNING_H
+#pragma once
 
 #include "ksieveui_private_export.h"
 #include <KMessageWidget>
@@ -22,4 +21,3 @@ public:
     void setWarningMessage(const QString &msg);
 };
 }
-#endif // SIEVESCRIPTDEBUGGERWARNING_H
