@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class SieveAccountTest : public QObject
     Q_OBJECT
 public:
     explicit SieveAccountTest(QObject *parent = nullptr);
-    ~SieveAccountTest();
+    ~SieveAccountTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
