@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef VACATIONCREATESCRIPTJOB_H
-#define VACATIONCREATESCRIPTJOB_H
+#pragma once
 
 #include <QObject>
 
@@ -66,4 +65,3 @@ private:
 };
 }
 
-#endif // VACATIONCREATESCRIPTJOB_H
