@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef VACATIONHELPERJOB_H
-#define VACATIONHELPERJOB_H
+#pragma once
 
 #include <QUrl>
 
@@ -40,4 +39,3 @@ private:
 };
 }
 
-#endif // VACATIONHELPERJOB_H
