@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef VACATIONPAGEWIDGET_H
-#define VACATIONPAGEWIDGET_H
+#pragma once
 
 #include <QUrl>
 #include <QWidget>
@@ -54,4 +53,3 @@ private:
 };
 }
 
-#endif // VACATIONPAGEWIDGET_H
