@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef CUSTOMMANAGESIEVEWIDGET_H
-#define CUSTOMMANAGESIEVEWIDGET_H
+#pragma once
 
 #include "util/util_p.h"
 #include <KSieveUi/SieveImapInstance>
@@ -41,4 +40,3 @@ private:
 };
 }
 
-#endif // CUSTOMMANAGESIEVEWIDGET_H
